The electricity, gas and water supplies are in order and well-maintained. | OiRA

Help

1. Sagatavošanās
2. Iesaiste
3. Novērtējums
   1. 1 Commercial manned guarding
      1. 1.1 Work environment (site related)
         1. 1.1.1 Slips, trips and falls are prevented.
         2. 1.1.2 Collisions, bumps, and jamming are prevented.
         3. 1.1.3 The electricity, gas and water supplies are in order and well-maintained.
         4. 1.1.4 Exposure to noise is prevented or controlled.
         5. 1.1.5 Exposure to chemical substances is prevented or controlled.
         6. 1.1.6 Exposure to biological substances is prevented or controlled.
         7. 1.1.7 Exposure to radiation is prevented or controlled.
         8. 1.1.8 Risks from ambient factors are prevented.
         9. 1.1.9 All necessary facilities are available and well maintained.
      2. 1.2 Fire prevention and emergency procedures
      3. 1.3 Work equipment
   2. 2 Mobile partrolling / intervention after alarm
   3. 3OSH management
   4. 4Maritime security
   5. Ω Jūsu pievienotie riski
   - Neatbildēts
   - Atlikts jautājums
   - Viss kārtībā
   - Uzmanību
4. Pārskats
5. Statuss 57%

   You've completed 57% of the risk assessment. When you've completed 85% of the risk assessment, you will be eligible for a certificate.

   With this certificate, you can apply for a reduction on your company's insurance rates. Learn more about the benefits…

Help

## The electricity, gas and water supplies are in order and well-maintained.

Jā Nē Nav attiecināms

### Measures

Select or describe the specific measures required to reduce the risk.

## Tipveida pasākums

Izvēlieties vienu tipveida pasākumu

Visual inspection of work areas. Pievienot Provide good equipment Pievienot Inform the private security guards Pievienot The private security guard reports correctly and immediately disfunction of electricity, gas and water systems. Pievienot

## Visual inspection of work areas.

Remove

#### Description

Make sure a visual inspection of work areas is carried out in order to identify the potential hazards of falls and slips. Check that the anti-fall fittings and protective measures are present and in good condition.

#### Expertise

Contrary to popular belief, Lorem Ipsum is not simply random text. It has roots in a piece of classical Latin literature from 45 BC, making it over 2000 years old.

Kura ir atbildīgā persona? Appoint someone in your company to be responsible for the implementation of this measure. This person will have the authority to take the steps described in the Plan and/or the responsibility to ensure that they are carried out. Budžets Although some measures do not cost any money, most do. The measures should therefore be budgeted for; include them in the annual budget round if necessary. Uzsākšanas datums Pabeigšanas datums

## Provide good equipment

Remove

#### Description

Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean commodo ligula eget dolor. Aenean massa.

#### Expertise

Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus.

Kura ir atbildīgā persona? Appoint someone in your company to be responsible for the implementation of this measure. This person will have the authority to take the steps described in the Plan and/or the responsibility to ensure that they are carried out. Budžets Although some measures do not cost any money, most do. The measures should therefore be budgeted for; include them in the annual budget round if necessary. Uzsākšanas datums Pabeigšanas datums

## Inform the private security guards

Remove

#### Description

Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean commodo ligula eget dolor. Aenean massa.

#### Expertise

Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus.

Kura ir atbildīgā persona? Appoint someone in your company to be responsible for the implementation of this measure. This person will have the authority to take the steps described in the Plan and/or the responsibility to ensure that they are carried out. Budžets Although some measures do not cost any money, most do. The measures should therefore be budgeted for; include them in the annual budget round if necessary. Uzsākšanas datums Pabeigšanas datums

## The private security guard reports correctly and immediately disfunction of electricity, gas and water systems.

Remove

#### Description

Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean commodo ligula eget dolor. Aenean massa.

#### Expertise

Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus.

Kura ir atbildīgā persona? Appoint someone in your company to be responsible for the implementation of this measure. This person will have the authority to take the steps described in the Plan and/or the responsibility to ensure that they are carried out. Budžets Although some measures do not cost any money, most do. The measures should therefore be budgeted for; include them in the annual budget round if necessary. Uzsākšanas datums Pabeigšanas datums

### Informācija

Ensure that the electrical system, as well as the gas and water supplies are safe.** Some examples: all the exposed conductive parts are connected to the earthing system; all safety devices and switches are in place and they work well; there are measures in place to protect electrical equipment from water. - The electricity, gas and water supplies at the client company must comply with the relevant safety regulations and be maintained by competent people in accordance with regulations. - There should be restricted access to electricity, gas and water premises.

### Resursi

#### Atsauces uz normatīvajiem aktiem

- 89/391/CEE Implementing measures to improve the health and safety of workers (framework directive).
- 89/654/EEC Directive on the minimum safety and health requirements for the workplace.
- 2006/95/EC Directive on the harmonisation of the laws of Member States relating to electrical equipment designed for use within certain voltage limits.

#### Papildu resursi riska novērtēšanai

- Lorem ipsum dolor sit.pdf
- Amet consectetuer.pdf

Komentāri

Scroll to top
Back

## risk-integrated-action-plan.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More